package com.gic.plug.web.controller;

import com.alibaba.fastjson.JSONObject;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.enterprise.error.ErrorCode;
import com.gic.plug.web.vo.CityVO;
import com.gic.plug.web.vo.CountyVO;
import com.gic.plug.web.vo.ProvinceVO;
import com.gic.store.dto.CityDTO;
import com.gic.store.dto.CountyDTO;
import com.gic.store.dto.ProvinceDTO;
import com.gic.store.service.ProvincesApiService;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import java.util.ArrayList;
import java.util.List;

@Controller
public class ProvincesController {
    @Autowired
    private ProvincesApiService provincesApiService;

    @RequestMapping("dict-district-list")
    @ResponseBody
    public Object provinces(String id, @RequestParam(defaultValue = "1")int type){
        switch (type){
            case 1:
                ServiceResponse<List<ProvinceDTO>> serviceResponse = this.provincesApiService.selectAllProvince();
                return RestResponse.success(EntityUtil.changeEntityListByJSON(ProvinceVO.class, serviceResponse.getResult()));
            case 2:
                ServiceResponse<List<CityDTO>> serviceResponse1 = this.provincesApiService.selectAllCity();
                if(serviceResponse1.isSuccess()){
                    List<CityDTO> list = serviceResponse1.getResult();
                    List<CityVO> resultList = new ArrayList<>();
                    for(CityDTO cityDTO : list){
                        if(cityDTO.getProvinceId().equals(id)){
                            resultList.add(EntityUtil.changeEntityByJSON(CityVO.class, cityDTO));
                        }
                    }
                    return RestResponse.success(resultList);
                }
            case 3:
                ServiceResponse<List<CountyDTO>> serviceResponse2 = this.provincesApiService.selectAllCounty();
                if(serviceResponse2.isSuccess()){
                    List<CountyDTO> list = serviceResponse2.getResult();
                    List<CountyDTO> resultList = new ArrayList<>();
                    for(CountyDTO countyDTO : list){
                        if(countyDTO.getCityId().equals(id)){
                            resultList.add(EntityUtil.changeEntityByJSON(CountyDTO.class, countyDTO));
                        }
                    }
                    return RestResponse.success(resultList);
                }
        }
        return RestResponse.success();
    }

    @RequestMapping("query-provinces")
    @ResponseBody
    public Object searchProvinces(String search){
        ServiceResponse<List<ProvinceDTO>> serviceResponse = this.provincesApiService.queryProvinces(search);
        if(serviceResponse.isSuccess()){
            return RestResponse.success(EntityUtil.changeEntityListByJSON(ProvinceVO.class, serviceResponse.getResult()));
        }
        return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
    }

    @RequestMapping("query-city")
    @ResponseBody
    public Object searchCitys(String search){
        if(StringUtils.isBlank(search)){
            return RestResponse.failure(ErrorCode.MISS_PARAMETER.getCode(), ErrorCode.MISS_PARAMETER.getMsg());
        }
        ServiceResponse<List<CityDTO>> serviceResponse = this.provincesApiService.queryCity(search);
        if(serviceResponse.isSuccess()){
            return RestResponse.success(EntityUtil.changeEntityListByJSON(CityVO.class, serviceResponse.getResult()));
        }
        return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
    }

    @RequestMapping("query-county")
    @ResponseBody
    public Object searchCounty(String search){
        if(StringUtils.isBlank(search)){
            return RestResponse.failure(ErrorCode.MISS_PARAMETER.getCode(), ErrorCode.MISS_PARAMETER.getMsg());
        }
        ServiceResponse<List<CountyDTO>> serviceResponse = this.provincesApiService.queryCounty(search);
        if(serviceResponse.isSuccess()){
            return RestResponse.success(EntityUtil.changeEntityListByJSON(CountyVO.class, serviceResponse.getResult()));
        }
        return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
    }

    @RequestMapping("query-district")
    @ResponseBody
    public RestResponse queryDistrictByIds(String ids){
        if(StringUtils.isBlank(ids)){
            return RestResponse.success();
        }
        List<String> result = new ArrayList<>();
        ServiceResponse<List<ProvinceDTO>> serviceResponse = this.provincesApiService.selectAllProvince();
        ServiceResponse<List<CityDTO>> serviceResponse1 = this.provincesApiService.selectAllCity();
        ServiceResponse<List<CountyDTO>> serviceResponse2 = this.provincesApiService.selectAllCounty();
        String[] idArr = ids.split(",");
        for(String id : idArr){
            if(serviceResponse.isSuccess()){
                List<ProvinceDTO> provinceDTOList = serviceResponse.getResult();
                for(ProvinceDTO provinceDTO : provinceDTOList){
                    if(id.equals(provinceDTO.getProvinceId())){
                        result.add(provinceDTO.getProvinceName());
                        continue;
                    }
                }
            }
            if(serviceResponse1.isSuccess()){
                List<CityDTO> cityDTOList = serviceResponse1.getResult();
                for(CityDTO cityDTO : cityDTOList){
                    if(id.equals(cityDTO.getCityId())){
                        result.add(cityDTO.getCityName());
                        continue;
                    }
                }
            }
            if(serviceResponse2.isSuccess()){
                List<CountyDTO> countyDTOList = serviceResponse2.getResult();
                for(CountyDTO countyDTO : countyDTOList){
                    if(id.equals(countyDTO.getCountyId())){
                        result.add(countyDTO.getCountyName());
                        continue;
                    }
                }
            }
        }
        return RestResponse.success(result);
    }

    @RequestMapping("dict-provinces-citys")
    @ResponseBody
    public RestResponse listProvincesCitys(){
        ServiceResponse<List<ProvinceDTO>> serviceResponse = this.provincesApiService.selectAllProvince();
        ServiceResponse<List<CityDTO>> serviceResponse1 = this.provincesApiService.selectAllCity();
        List<JSONObject> result = new ArrayList<>();
        if(serviceResponse.isSuccess()){
            List<ProvinceDTO> list = serviceResponse.getResult();
            if(CollectionUtils.isNotEmpty(list)){
                for(ProvinceDTO provinceDTO : list){
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put("provinceId", provinceDTO.getProvinceId());
                    jsonObject.put("provinceName", provinceDTO.getProvinceName());
                    if(serviceResponse1.isSuccess()){
                        List<CityDTO> cityDTOList = serviceResponse1.getResult();
                        if(CollectionUtils.isNotEmpty(cityDTOList)){
                            List<JSONObject> jsonObjectList = new ArrayList<>();
                            for(CityDTO cityDTO : cityDTOList){
                                if(cityDTO.getProvinceId().equals(provinceDTO.getProvinceId())){
                                    JSONObject object = new JSONObject();
                                    object.put("cityId", cityDTO.getCityId());
                                    object.put("cityName", cityDTO.getCityName());
                                    jsonObjectList.add(object);
                                }
                            }
                            jsonObject.put("children", jsonObjectList);
                        }
                    }
                    result.add(jsonObject);
                }
            }
        }
        return RestResponse.success(result);
    }
}
