package com.gic.plug.web.controller;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.utils.UserDetailUtils;
import com.gic.plug.web.vo.StoreFieldRegionVO;
import com.gic.plug.web.vo.StoreFieldSelectVO;
import com.gic.redis.data.util.RedisUtil;
import com.gic.store.constant.StoreFieldDateEnum;
import com.gic.store.constant.StoreFieldTextEnum;
import com.gic.store.constant.StoreFieldTypeEnum;
import com.gic.store.constant.StoreGroupConstant;
import com.gic.store.dto.StoreFieldDTO;
import com.gic.store.dto.StoreFieldSelectDTO;
import com.gic.store.service.StoreFieldApiService;
import com.gic.store.service.StoreFieldSelectApiService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author guojx
 * @date 2019/7/15 9:21 AM
 */
@RestController
@RequestMapping("/store-field")
public class StoreFieldController {
    private static final Logger logger = LoggerFactory.getLogger(StoreFieldController.class);

    @Autowired
    private StoreFieldApiService storeFieldApiService;
    @Autowired
    private StoreFieldSelectApiService storeFieldSelectApiService;

    @RequestMapping("/list-store-field-type")
    public RestResponse listStoreFieldType() {
        Map<Integer, String> result = new HashMap<>(16);
        for (StoreFieldTypeEnum typeEnum : StoreFieldTypeEnum.values()) {
            result.put(typeEnum.getCode(), typeEnum.getMessage());
        }
        return RestResponse.success(result);
    }

    @RequestMapping("/list-store-field-date-type")
    public RestResponse listStoreFieldDateType() {
        Map<Integer, String> result = new HashMap<>(16);
        for (StoreFieldDateEnum typeEnum : StoreFieldDateEnum.values()) {
            result.put(typeEnum.getCode(), typeEnum.getMessage());
        }
        return RestResponse.success(result);
    }

    /**
     * 文本类型
     * @return
     */
    @RequestMapping("/list-store-field-text-type")
    public RestResponse listStoreFieldTextType() {
        Map<Integer, String> result = new HashMap<>(16);
        for (StoreFieldTextEnum typeEnum : StoreFieldTextEnum.values()) {
            result.put(typeEnum.getCode(), typeEnum.getMessage());
        }
        return RestResponse.success(result);
    }

    @RequestMapping("/list-store-field-by-region-id")
    public RestResponse listStoreFieldByRegionId(Integer regionId) {
        Integer enterpriseId = UserDetailUtils.getUserDetail().getEnterpriseId();
        if (regionId == null) {
            RestResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "域ID不能为空");
        }
        ServiceResponse<List<StoreFieldDTO>> result = storeFieldApiService.listStoreFieldByRegionId(regionId);
        if (result.isSuccess()) {
            return RestResponse.success(transferDtoToVo(result.getResult(), enterpriseId));
        } else {
            return RestResponse.failure(result.getCode(), result.getMessage());
        }
    }

    @RequestMapping("/list-store-field")
    public RestResponse listStoreField(String search) {
        Integer enterpriseId = UserDetailUtils.getUserDetail().getEnterpriseId();
        ServiceResponse<List<StoreFieldDTO>> result = storeFieldApiService.listStoreField(StoreGroupConstant.TEST_ENTERPRISE_ID, search);

        if (result.isSuccess()) {
            return RestResponse.success(transferDtoToVo(result.getResult(), enterpriseId));
        } else {
            return RestResponse.failure(result.getCode(), result.getMessage());
        }
    }

    @RequestMapping("/list-store-field-select")
    public RestResponse listStoreFieldSelect(String search, Integer storeFieldId) {
        ServiceResponse<List<StoreFieldSelectDTO>> result = storeFieldSelectApiService.listStoreFieldSelect(storeFieldId, search);
        if (result.isSuccess()) {
            return RestResponse.success(EntityUtil.changeEntityListNew(StoreFieldSelectVO.class, result.getResult()));
        } else {
            return RestResponse.failure(result.getCode(), result.getMessage());
        }
    }

    private List<StoreFieldRegionVO> transferDtoToVo(List<StoreFieldDTO> dtoList, Integer enterpriseId) {
        String key = "enterprise:store:storeField:"+enterpriseId+":";
        List<StoreFieldRegionVO> voList = new ArrayList<>(dtoList.size());
        for (StoreFieldDTO dto : dtoList) {
            //不需要文本类型字段
            if (dto.getStoreFieldType().intValue() != StoreFieldTypeEnum.TEXT.getCode()) {
                Object obj = RedisUtil.getCache(key+dto.getStoreFieldId());
                if(obj != null){
                    StoreFieldRegionVO vo = EntityUtil.changeEntityNew(StoreFieldRegionVO.class, dto);
                    vo.setStoreFieldKey(obj.toString());
                    if(vo.getStoreFieldType().intValue() == StoreFieldTypeEnum.DATE.getCode()){
                        JSONObject json = JSON.parseObject(dto.getStoreFieldDetail());
                        vo.setDateType(json.getIntValue("dateType"));
                    }
                    voList.add(vo);
                }
            }
        }
        return voList;
    }
}
