package com.gic.plug.web.controller.goods;

import com.alibaba.fastjson.JSONObject;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.goods.api.dto.GoodsSkuDTO;
import com.gic.goods.api.service.GoodsApiService;
import com.gic.plug.web.vo.goods.GoodsVO;
import com.gic.search.business.api.constant.enums.OperateEnum;
import com.gic.search.business.api.dto.DynamicSearchDTO;
import com.gic.search.business.api.dto.ESResponseQueryBatchDTO;
import com.gic.search.business.api.service.EsBusinessOperaApiService;
import com.gic.search.business.api.utils.QueryConditionAssemblyUtil;
import com.gic.widget.screening.api.service.EsScreeningSearchService;
import org.apache.commons.collections.CollectionUtils;
import org.apache.curator.shaded.com.google.common.collect.Lists;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
  * @ClassName: GoodsTagController
  * @Description: 商品标签相关接口
  * @author xub
  * @date 2019/8/29 上午10:03
  */
@RestController
public class GoodsController {

    @Autowired
    private EsBusinessOperaApiService esBusinessOperaApiService;

    @Autowired
    private EsScreeningSearchService esScreeningSearchService;

    @Autowired
    private GoodsApiService goodsApiService;


    /**
     * @Description: 查询所有（不分页）
     * @author xub
     */
    @GetMapping("list-goods")
    public RestResponse ListGoods(@RequestParam(value = "currentPage", defaultValue = "1") Integer currentPage,
                                 @RequestParam(value = "pageSize", defaultValue = "20") Integer pageSize, Long goodsDomainId,String search,String channelCode) {
        ServiceResponse<ESResponseQueryBatchDTO> serviceResponse = searchES(currentPage,pageSize,goodsDomainId,search,channelCode);
        if (serviceResponse.isSuccess()) {
            return RestResponse.success(serviceResponse.getResult());
        }
        return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
    }


    /**
     * @Description: 查询所有（不分页）
     * @author xub
     */
    @GetMapping("list-sku")
    public RestResponse ListSku(@RequestParam(value = "currentPage", defaultValue = "1") Integer currentPage,
                                 @RequestParam(value = "pageSize", defaultValue = "20") Integer pageSize, Long goodsDomainId,String search,String channelCode) {
        ServiceResponse<ESResponseQueryBatchDTO> serviceResponse = searchES(currentPage,pageSize,goodsDomainId,search ,channelCode);
        if (!serviceResponse.isSuccess()) {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
        //商品信息
        List<JSONObject> list = serviceResponse.getResult().getRes();
        if (CollectionUtils.isEmpty(list)) {
            return RestResponse.success(serviceResponse.getResult());
        }
        //1、获取商品信息
        List<GoodsVO> goodsVOS = Lists.newArrayList();
        for (JSONObject jsonObject : list) {
            GoodsVO goodsVO = JSONObject.toJavaObject(jsonObject, GoodsVO.class);
            goodsVOS.add(goodsVO);
        }
       //2、获取商品ID信息
        List<Long> goodsIds = goodsVOS.stream().mapToLong(GoodsVO::getGoodsId).boxed().collect(Collectors.toList());
        ServiceResponse<List<GoodsSkuDTO>> skuResponse = goodsApiService.listSkuByGoods(goodsIds);
        if (!skuResponse.isSuccess()) {
            return RestResponse.failure(skuResponse.getCode(), skuResponse.getMessage());

        }
        //3、获取sku信息 同时存储在map中
        List<GoodsSkuDTO> skuDTOList = skuResponse.getResult();
        if (CollectionUtils.isEmpty(skuDTOList)) {
            return RestResponse.success(serviceResponse.getResult());
        }
        Map<Long, List<GoodsSkuDTO>> goodsIdAndskuDto = skuDTOList.stream().collect(Collectors.groupingBy(GoodsSkuDTO::getGoodsId));
        //4、商品信息中包含是sku信息
        for (GoodsVO goodsVO : goodsVOS) {
            if (goodsIdAndskuDto.containsKey(goodsVO.getGoodsId())) {
                List<GoodsVO.SkuVO> skuVOList = EntityUtil.changeEntityListByOrika(GoodsVO.SkuVO.class,goodsIdAndskuDto.get(goodsVO.getGoodsId()));
                goodsVO.setSkuVOList(skuVOList);
            }
        }
        return RestResponse.success(goodsVOS);
    }


    private ServiceResponse<ESResponseQueryBatchDTO> searchES( Integer currentPage,Integer pageSize, Long goodsDomainId,String search,String channelCode) {
        DynamicSearchDTO searchDTO = new DynamicSearchDTO();
        String esName = esScreeningSearchService.getCurrentEsName("goods-test-123456", "goods-search");
        searchDTO.setIndexName(esName);
        searchDTO.setColumnCategoryCode("goods-search");
        searchDTO.setEnterpriseId("goods-test-123456");
        searchDTO.setType("mapper_type");
        searchDTO.setBegin(currentPage);
        searchDTO.setRecordNumber(pageSize);
        JSONObject goodsCodeJson = QueryConditionAssemblyUtil.createSimpleQueryNode("goodsCode", OperateEnum.OPERATE_LIKE, search);
        JSONObject goodsNameJson = QueryConditionAssemblyUtil.createSimpleQueryNode("goodsName", OperateEnum.OPERATE_LIKE, search);
        JSONObject goodsDomainIdJson = QueryConditionAssemblyUtil.createSimpleQueryNode("channelCodeDomainId", OperateEnum.OPERATE_EQ, channelCode+"-"+goodsDomainId);
        JSONObject nameAndCodeJson = QueryConditionAssemblyUtil.addQueryNodeForSiblin(goodsCodeJson, goodsNameJson, OperateEnum.OPERATE_OR);
        JSONObject json = QueryConditionAssemblyUtil.addQueryNodeForSiblin(nameAndCodeJson, goodsDomainIdJson, OperateEnum.OPERATE_AND);
        searchDTO.setSearchJson(json);
        ServiceResponse<ESResponseQueryBatchDTO> serviceResponse = esBusinessOperaApiService.queryDataBatch(searchDTO, false, null);
        return serviceResponse;
    }
}
