package com.gic.plug.web.controller.goods;

import java.util.*;

import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.goods.api.dto.GoodsDomainDTO;
import com.gic.goods.api.dto.GoodsRightsSelectorDTO;
import com.gic.goods.api.service.GoodsDomainApiService;
import com.gic.goods.api.service.GoodsRightsSelectorApiService;
import com.gic.goods.api.util.Constant;
import com.gic.plug.web.vo.goods.GoodsChannelVO;
import com.gic.plug.web.vo.goods.GoodsDomainVO;

@RestController
public class GoodsDomainController {

    @Autowired
    private GoodsDomainApiService goodsDomainApiService;

    @Autowired
    private GoodsRightsSelectorApiService goodsRightsSelectorApiService;

    /**
     * @Title: getAllGoodsDomianListWith
     * @Description: 权限筛选器选择权限
     * @author majia
     * @return  com.gic.commons.webapi.reponse.RestResponse
     * @throws
     */
    @RequestMapping("/get-all-goods-domain-list-for-rights")
    public RestResponse getAllGoodsDomainListForRights() {
        ServiceResponse<List<GoodsDomainDTO>> serviceResponse = goodsDomainApiService.listAll(Constant.TEST_ENTERPRISE_ID, null);
        if (!serviceResponse.isSuccess()) {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
        return listGoodsDomain(true, serviceResponse.getResult(), null);
    }

    /**
    * @Title: getAllGoodsDomianListWith
    * @Description: 查询企业下所有的域，拼接成channelVO返回
    * @author majia
    * @return  com.gic.commons.webapi.reponse.RestResponse
    * @throws
    */
    @RequestMapping("/get-all-goods-domain-list")
    public RestResponse getAllGoodsDomianList() {
        ServiceResponse<GoodsRightsSelectorDTO> selectorDTOServiceResponse = goodsRightsSelectorApiService.getGoodsRightsSelector(Constant.TEST_GOODS_RIGHTS_SELECTOR_ID);
        if (!selectorDTOServiceResponse.isSuccess() || selectorDTOServiceResponse.getResult() == null ||
                selectorDTOServiceResponse.getResult().getHasRights() == Constant.NO) {
            return RestResponse.success(Collections.EMPTY_LIST);
        }
        ServiceResponse<List<GoodsDomainDTO>> serviceResponse = goodsDomainApiService.listAll(Constant.TEST_ENTERPRISE_ID, null);
        // 是否最高权限
        boolean isHighestRights = true;
        JSONObject json = null;
        if (Constant.TEST_GOODS_RIGHTS_SELECTOR_ID != null) {
            isHighestRights = false;
            if (selectorDTOServiceResponse.isSuccess()) {
                GoodsRightsSelectorDTO goodsRightsSelectorDTO = selectorDTOServiceResponse.getResult();
                if (goodsRightsSelectorDTO != null) {
                    json = JSONObject.parseObject(goodsRightsSelectorDTO.getGoodsRightsDomains());
                    if (json.isEmpty()) {
                        isHighestRights = true;
                    }
                }
            }
        }
        if (!serviceResponse.isSuccess()) {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
        return listGoodsDomain(isHighestRights, serviceResponse.getResult(), json);
    }

    private RestResponse listGoodsDomain(boolean isHighestRights, List<GoodsDomainDTO> goodsDomainDTOList, JSONObject json) {
        Map<String, List<GoodsDomainDTO>> map = new TreeMap<>();
        if (CollectionUtils.isEmpty(goodsDomainDTOList)) {
            return RestResponse.success(Collections.EMPTY_LIST);
        }
        for (GoodsDomainDTO goodsDomainDTO : goodsDomainDTOList) {
            if (CollectionUtils.isNotEmpty(goodsDomainDTO.getChannels())){
                for (String channelCode : goodsDomainDTO.getChannels()) {
                    if (isHighestRights) {  // 最高权限所有都显示
                        map.putIfAbsent(channelCode, new ArrayList<>());
                        map.get(channelCode).add(goodsDomainDTO);
                    } else { //非最高权限按权限下有什么就刷什么来
                        if (json != null && json.containsKey(channelCode)) {
                            map.putIfAbsent(channelCode, new ArrayList<>());
                            JSONArray array = json.getJSONArray(channelCode);
                            if (CollectionUtils.isNotEmpty(array) && array.contains(goodsDomainDTO.getGoodsDomainId())) {
                                map.get(channelCode).add(goodsDomainDTO);
                            }
                        }
                    }

                }
            }
        }
        List<GoodsChannelVO> resultList = new ArrayList<>();
        for (Map.Entry<String, List<GoodsDomainDTO>> entry : map.entrySet()) {
            GoodsChannelVO goodsChannelVO = new GoodsChannelVO();
            goodsChannelVO.setChannelCode(entry.getKey());
            goodsChannelVO.setChannelName(Constant.CHANNEL_CODE_AND_NAME.get(entry.getKey()));
            goodsChannelVO.setSceneCode(Constant.CHANNEL_CODE_AND_SCENE.get(entry.getKey()));
            goodsChannelVO.setGoodsDomainList(new ArrayList<>());
            for (GoodsDomainDTO goodsDomainDTO : entry.getValue()) {
                GoodsDomainVO goodsDomainVO = new GoodsDomainVO();
                goodsDomainVO.setDomainCode(goodsDomainDTO.getCode());
                goodsDomainVO.setDomainId(goodsDomainDTO.getGoodsDomainId());
                goodsDomainVO.setDomainName(goodsDomainDTO.getName());
                goodsChannelVO.getGoodsDomainList().add(goodsDomainVO);
            }
            resultList.add(goodsChannelVO);
        }
        return RestResponse.success(resultList);
    }

}
