package com.gic.plug.web.controller.goods;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.goods.api.dto.GoodsRightsSelectorDTO;
import com.gic.goods.api.service.GoodsRightsSelectorApiService;
import com.gic.goods.api.util.Constant;
import com.gic.plug.web.qo.goods.GoodsRightsSelectorSaveQO;
import com.gic.plug.web.qo.goods.GoodsRightsSelectorUpdateQO;
import com.gic.plug.web.vo.goods.GoodsRightsSelectorVO;

@RestController
public class GoodsRightsSelectorController {

    @Autowired
    private GoodsRightsSelectorApiService goodsRightsSelectorApiService;

    /**
    * @Title: goodsRightsSelectorSave
    * @Description: 保存商品选择器权限版
    * @author majia
     * @param goodsRightsSelectorSaveQO
    * @return  com.gic.commons.webapi.reponse.RestResponse
    * @throws
    */
    @RequestMapping("/goods-rights-selector-save")
    public RestResponse goodsRightsSelectorSave(GoodsRightsSelectorSaveQO goodsRightsSelectorSaveQO) {
        GoodsRightsSelectorDTO goodsRightsSelectorDTO = EntityUtil.changeEntityByOrika(GoodsRightsSelectorDTO.class, goodsRightsSelectorSaveQO);
        if (goodsRightsSelectorDTO.getHasRights() == null) {
            goodsRightsSelectorDTO.setHasRights(Constant.NO);
        }
        ServiceResponse<GoodsRightsSelectorDTO> serviceResponse = goodsRightsSelectorApiService.saveGoodsRightsSelector(goodsRightsSelectorDTO);
        if (serviceResponse.isSuccess()) {
            goodsRightsSelectorDTO = serviceResponse.getResult();
            return RestResponse.success(EntityUtil.changeEntityByOrika(GoodsRightsSelectorVO.class, goodsRightsSelectorDTO));
        }
        return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
    }

    @RequestMapping("/goods-rights-selector-update")
    public RestResponse goodsRightsSelectorSave(GoodsRightsSelectorUpdateQO goodsRightsSelectorUpdateQO) {
        GoodsRightsSelectorDTO goodsRightsSelectorDTO = EntityUtil.changeEntityByOrika(GoodsRightsSelectorDTO.class, goodsRightsSelectorUpdateQO);
        ServiceResponse<GoodsRightsSelectorDTO> serviceResponse = goodsRightsSelectorApiService.updateGoodsRightsSelector(goodsRightsSelectorDTO);
        if (serviceResponse.isSuccess()) {
            goodsRightsSelectorDTO = serviceResponse.getResult();
            return RestResponse.success(EntityUtil.changeEntityByOrika(GoodsRightsSelectorVO.class, goodsRightsSelectorDTO));
        }
        return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
    }

    @RequestMapping("/get-goods-rights-selector")
    public RestResponse getGoodsRightsSelector(Long goodsRightsSelectorId) {
        ServiceResponse<GoodsRightsSelectorDTO> serviceResponse = goodsRightsSelectorApiService.getGoodsRightsSelector(goodsRightsSelectorId);
        if (serviceResponse.isSuccess()) {
            GoodsRightsSelectorDTO goodsRightsSelectorDTO = serviceResponse.getResult();
            return RestResponse.success(EntityUtil.changeEntityByOrika(GoodsRightsSelectorVO.class, goodsRightsSelectorDTO));
        }
        return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
    }

}
