package com.gic.plug.web.controller.goods;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.goods.api.dto.GoodsRightsSelectorDTO;
import com.gic.goods.api.dto.GoodsSelectorDTO;
import com.gic.goods.api.service.GoodsRightsSelectorApiService;
import com.gic.goods.api.service.GoodsSelectorApiService;
import com.gic.goods.api.util.Constant;
import com.gic.plug.web.qo.goods.GoodsSelectorSaveQO;
import com.gic.plug.web.qo.goods.GoodsSelectorUpdateQO;
import com.gic.plug.web.vo.goods.GoodsSelectorVO;

@RestController
public class GoodsSelectorController {

    @Autowired
    private GoodsSelectorApiService goodsSelectorApiService;

    @Autowired
    private GoodsRightsSelectorApiService goodsRightsSelectorApiService;

    @RequestMapping("goods-selector-show-back")
    public RestResponse goodsSelectorShowBack(Long goodsSelectorId) {
        ServiceResponse<GoodsSelectorDTO> serviceResponse = goodsSelectorApiService.getGoodsSelector(goodsSelectorId);
        if (serviceResponse.isSuccess()) {
            return RestResponse.success(serviceResponse.getResult().getGoodsSearchValue());
        }
        return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
    }

    @RequestMapping("get-goods-selector")
    public RestResponse getGoodsSelector(Long goodsSelectorId) {
        ServiceResponse<GoodsSelectorDTO> serviceResponse = goodsSelectorApiService.getGoodsSelector(goodsSelectorId);
        if (serviceResponse.isSuccess()) {
            GoodsSelectorVO goodsSelectorVO = EntityUtil.changeEntityByOrika(GoodsSelectorVO.class, serviceResponse.getResult());
            return RestResponse.success(goodsSelectorVO);
        }
        return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
    }


    @RequestMapping("goods-selector-edit-show-back")
    public RestResponse goodsSelectorEditShowBack(Long goodsSelectorId) {
        ServiceResponse<GoodsSelectorDTO> serviceResponse = goodsSelectorApiService.getGoodsSelector(goodsSelectorId);
        if (serviceResponse.isSuccess()) {
            return RestResponse.success(serviceResponse.getResult().getGoodsSearchEdit());
        }
        return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
    }

    @RequestMapping("goods-selector-save")
    public RestResponse goodsSelectorSave(GoodsSelectorSaveQO goodsSelectorSaveQO) {
        GoodsSelectorDTO goodsSelectorDTO = EntityUtil.changeEntityByOrika(GoodsSelectorDTO.class, goodsSelectorSaveQO);
        goodsSelectorDTO.setEnterpriseId(Constant.TEST_ENTERPRISE_ID);
        ServiceResponse<GoodsRightsSelectorDTO> goodsRightsSelectorDTOServiceResponse = goodsRightsSelectorApiService.getGoodsRightsSelector(Constant.TEST_GOODS_RIGHTS_SELECTOR_ID);
        if (!goodsRightsSelectorDTOServiceResponse.isSuccess()) {
            return RestResponse.failure(goodsRightsSelectorDTOServiceResponse.getCode(), goodsRightsSelectorDTOServiceResponse.getMessage());
        }
        GoodsRightsSelectorDTO goodsRightsSelectorDTO = goodsRightsSelectorDTOServiceResponse.getResult();
        goodsSelectorDTO.setHasRights(goodsRightsSelectorDTO.getHasRights());
        goodsSelectorDTO.setGoodsSearchRightValue(goodsRightsSelectorDTO.getGoodsRightsSearchValue());
        goodsSelectorDTO.setGoodsSearchRightText(goodsRightsSelectorDTO.getGoodsRightsSearchText());
        ServiceResponse<GoodsSelectorDTO> serviceResponse = goodsSelectorApiService.saveGoodsSelector(goodsSelectorDTO);
        if (serviceResponse.isSuccess()) {
            goodsSelectorDTO = serviceResponse.getResult();
            GoodsSelectorVO goodsSelectorVO = EntityUtil.changeEntityByOrika(GoodsSelectorVO.class, goodsSelectorDTO);
            return RestResponse.success(goodsSelectorVO);
        }
        return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
    }


    @RequestMapping("change-goods-rights-for-selector")
    public RestResponse changeGoodsRightsForSelector(Long goodsSelectorId) {
        ServiceResponse<GoodsRightsSelectorDTO> goodsRightsSelectorDTOServiceResponse = goodsRightsSelectorApiService.getGoodsRightsSelector(Constant.TEST_GOODS_RIGHTS_SELECTOR_ID);
        if (!goodsRightsSelectorDTOServiceResponse.isSuccess()) {
            return RestResponse.failure(goodsRightsSelectorDTOServiceResponse.getCode(), goodsRightsSelectorDTOServiceResponse.getMessage());
        }
        if (goodsSelectorId == null) {
            GoodsRightsSelectorDTO goodsRightsSelectorDTO = new GoodsRightsSelectorDTO();
            goodsRightsSelectorDTO.setGoodsRightsSearchText(goodsRightsSelectorDTOServiceResponse.getResult().getGoodsRightsSearchText());
            goodsRightsSelectorDTO.setGoodsRightsSearchValue(goodsRightsSelectorDTOServiceResponse.getResult().getGoodsRightsSearchValue());
            goodsRightsSelectorDTO.setHasRights(goodsRightsSelectorDTOServiceResponse.getResult().getHasRights());
            return  RestResponse.success(goodsRightsSelectorDTO);
        }
        GoodsRightsSelectorDTO goodsRightsSelectorDTO = goodsRightsSelectorDTOServiceResponse.getResult();
        ServiceResponse<GoodsSelectorDTO> serviceResponse =  goodsSelectorApiService.updateGoodsSelectorRights(goodsSelectorId,
                goodsRightsSelectorDTO.getGoodsRightsSearchText(), goodsRightsSelectorDTO.getGoodsRightsSearchValue(), goodsRightsSelectorDTO.getHasRights());
        if (!serviceResponse.isSuccess()) {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
        return RestResponse.success(serviceResponse.getResult());
    }



    @RequestMapping("goods-selector-update")
    public RestResponse goodsSelectorUpdate(GoodsSelectorUpdateQO goodsSelectorUpdateQO) {
        GoodsSelectorDTO goodsSelectorDTO = EntityUtil.changeEntityByOrika(GoodsSelectorDTO.class, goodsSelectorUpdateQO);
        ServiceResponse<GoodsSelectorDTO> serviceResponse = goodsSelectorApiService.updateGoodsSelector(goodsSelectorDTO);
        if (serviceResponse.isSuccess()) {
            goodsSelectorDTO = serviceResponse.getResult();
            GoodsSelectorVO goodsSelectorVO = EntityUtil.changeEntityByOrika(GoodsSelectorVO.class, goodsSelectorDTO);
            return RestResponse.success(goodsSelectorVO);
        }
        return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
    }
}
