package com.gic.plug.web.strategy.impl;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.plug.web.strategy.ScreenBackStrategy;
import com.gic.plug.web.utils.ComputeBackUtil;
import com.gic.store.constant.CreateTypeEnum;
import com.gic.store.constant.StoreCompleteEnum;
import com.gic.store.constant.StoreESFieldsEnum;
import com.gic.store.constant.StoreStatusEnum;
import com.gic.store.dto.StoreDictDTO;
import com.gic.store.service.StoreDictApiService;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Component
public class StoreSelectBackImpl implements ScreenBackStrategy {
    @Autowired
    private StoreDictApiService storeDictApiService;
    private Map<String, String> methodMap = new HashMap<>();

    @PostConstruct
    public void init(){
        methodMap.put(StoreESFieldsEnum.STATUS.getField(), "storeStatusBack");
        methodMap.put(StoreESFieldsEnum.COMPLETESTATUS.getField(), "storeCompleteBack");
        methodMap.put(StoreESFieldsEnum.CREATETYPE.getField(), "storeCreateTypeBack");
        methodMap.put(StoreESFieldsEnum.STORETYPE.getField(), "storeTypeBack");
        methodMap.put(StoreESFieldsEnum.ERPSTATUS.getField(), "erpStatusBack");
    }
    @Override
    public String screenBack(String compute, String value, String key, Integer enterpriseId){
        String methodName = methodMap.get(key);
        if(StringUtils.isNotBlank(methodName)){
            try {
                try {
                    Method method = this.getClass().getMethod(methodName, Class.forName(compute.getClass().getCanonicalName()),
                            Class.forName(value.getClass().getCanonicalName()),Class.forName(enterpriseId.getClass().getCanonicalName()));
                    try {
                        String message = (String)method.invoke(this, compute, value, enterpriseId);
                        return message;
                    } catch (IllegalAccessException e) {
                        e.printStackTrace();
                    } catch (InvocationTargetException e) {
                        e.printStackTrace();
                    }
                } catch (ClassNotFoundException e) {
                    e.printStackTrace();
                }
            } catch (NoSuchMethodException e) {
                e.printStackTrace();
            }
        }
        return null;
    }

    //单选
    public String storeStatusBack(String compute, String value, Integer enterpriseId){
        if(StringUtils.isNotBlank(value)){
            StringBuilder stringBuilder = new StringBuilder(StoreESFieldsEnum.STATUS.getDesc()).append(" ");
            stringBuilder.append(ComputeBackUtil.getComputeBack(compute)).append(" ");
            for(StoreStatusEnum storeStatusEnum : StoreStatusEnum.values()){
                if(storeStatusEnum.getCode() == Integer.valueOf(value)){
                    stringBuilder.append("【").append(storeStatusEnum.getMessage()).append("】 ");
                }
            }
            return stringBuilder.toString();
        }
        return null;
    }
    //单选
    public String storeCompleteBack(String compute, String value, Integer enterpriseId){
        if(StringUtils.isNotBlank(value)){
            StringBuilder stringBuilder = new StringBuilder(StoreESFieldsEnum.COMPLETESTATUS.getDesc()).append(" ");
            stringBuilder.append(ComputeBackUtil.getComputeBack(compute)).append(" ");
            for(StoreCompleteEnum storeStatusEnum : StoreCompleteEnum.values()){
                if(storeStatusEnum.getCode() == Integer.valueOf(value)){
                    stringBuilder.append("【").append(storeStatusEnum.getMessage()).append("】 ");
                }
            }
            return stringBuilder.toString();
        }
        return null;
    }
    //多选
    public String storeCreateTypeBack(String compute, String value, Integer enterpriseId){
        if(StringUtils.isNotBlank(value)){
            StringBuilder stringBuilder = new StringBuilder(StoreESFieldsEnum.CREATETYPE.getDesc()).append(" ");
            stringBuilder.append(ComputeBackUtil.getComputeBack(compute)).append(" ");
            String[] valueArr = value.split(" ");
            for(String v : valueArr){
                for(CreateTypeEnum createTypeEnum : CreateTypeEnum.values()){
                    if(createTypeEnum.getCode() == Integer.valueOf(v)){
                        stringBuilder.append("【").append(createTypeEnum.getMessage()).append("】 ");
                    }
                }
            }
            return stringBuilder.toString();
        }
        return null;
    }
    //多选
    public String storeTypeBack(String compute, String value, Integer enterpriseId){
        if(StringUtils.isNotBlank(value)){
            String[] valueArr = value.split(" ");
            ServiceResponse<List<StoreDictDTO>> serviceResponse = this.storeDictApiService.listStoreType(enterpriseId);
            if(serviceResponse.isSuccess()){
                List<StoreDictDTO> list = serviceResponse.getResult();
                StringBuilder stringBuilder = new StringBuilder(StoreESFieldsEnum.STORETYPE.getDesc());
                stringBuilder.append(" ").append(ComputeBackUtil.getComputeBack(compute));
                for(StoreDictDTO dictDTO : list){
                    for(String v : valueArr){
                        if(dictDTO.getValue().equals(v)){
                            stringBuilder.append(" 【");
                            stringBuilder.append(dictDTO.getKey()).append("】 ");
                        }
                    }
                }
                return stringBuilder.toString();
            }
        }
        return null;
    }
    //多选
    public String erpStatusBack(String compute, String value, Integer enterpriseId){
        if(StringUtils.isNotBlank(value)){
            String[] valueArr = value.split(" ");
            ServiceResponse<List<StoreDictDTO>> serviceResponse = this.storeDictApiService.listStoreStatus(enterpriseId);
            if(serviceResponse.isSuccess()){
                List<StoreDictDTO> list = serviceResponse.getResult();
                StringBuilder stringBuilder = new StringBuilder(StoreESFieldsEnum.ERPSTATUS.getDesc());
                stringBuilder.append(" ").append(ComputeBackUtil.getComputeBack(compute));
                for(StoreDictDTO dictDTO : list){
                    for(String v : valueArr){
                        if(dictDTO.getValue().equals(v)){
                            stringBuilder.append(" 【");
                            stringBuilder.append(dictDTO.getKey()).append("】 ");
                        }
                    }
                }
                return stringBuilder.toString();
            }
        }
        return null;
    }
}
